@@ -121,8 +121,8 @@ sub attract {
     my $ed            = int(rand(360));
     my $gr            = (rand(10) / 10);
     my $mode          = int(rand(4));
-    my $type          = int(rand(6));
-    my $size          = int(rand(3));
+    my $type          = int(rand(13));
+    my $size          = 1; # int(rand(6)) + 1;
     my $arc           = int(rand(3));
     my $filled        = int(rand(2));
 
